@@ -424,6 +424,18 @@ class Eniam():
         {valence_rules_str}
         """
 
+    def lexicon_str(self):
+        return "" if self.lexicon_content is None else self.lexicon_content
+
+    def valence_str(self):
+        return "" if self.valence_content is None else self.valence_content
+
+    def mwe_str(self):
+        return "" if self.mwe is None else self.mwe
+
+    def ne_str(self):
+        return "" if self.ne is None else self.ne
+
     def dom(self, input_text, silent=True):
         p = run_domparser(["--no-sem", "--no-def-cat"], PIPE, PIPE, self.lexicon_content, self.valence_content, self.mwe, self.ne)
         q_out = Queue()
